@@ -12,6 +12,8 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
+#include <libpanel-util/panel-list.h>
+
 #include "applet.h"
 #include "panel-widget.h"
 #include "button-widget.h"
@@ -203,7 +205,7 @@ add_all_move_bindings (PanelWidget *panel)
 static void
 panel_widget_force_grab_focus (GtkWidget *widget)
 {
-	gboolean can_focus = GTK_WIDGET_CAN_FOCUS (widget);
+	gboolean can_focus = gtk_widget_get_can_focus (widget);
 	/*
 	 * This follows what gtk_socket_claim_focus() does
 	 */
@@ -229,18 +231,18 @@ remove_tab_bindings (GtkBindingSet    *binding_set,
 		     GdkModifierType   modifiers,
 		     gboolean          next)
 {
-	gtk_binding_entry_clear (binding_set, GDK_Tab, modifiers);
-  	gtk_binding_entry_clear (binding_set, GDK_KP_Tab, modifiers);
+	gtk_binding_entry_remove (binding_set, GDK_Tab, modifiers);
+  	gtk_binding_entry_remove (binding_set, GDK_KP_Tab, modifiers);
 }
 
 static void
 remove_move_bindings (GtkBindingSet    *binding_set,
 		      GdkModifierType   modifiers)
 {
-	gtk_binding_entry_clear (binding_set, GDK_Up, modifiers);
-	gtk_binding_entry_clear (binding_set, GDK_Down, modifiers);
-	gtk_binding_entry_clear (binding_set, GDK_Left, modifiers);
-	gtk_binding_entry_clear (binding_set, GDK_Right, modifiers);
+	gtk_binding_entry_remove (binding_set, GDK_Up, modifiers);
+	gtk_binding_entry_remove (binding_set, GDK_Down, modifiers);
+	gtk_binding_entry_remove (binding_set, GDK_Left, modifiers);
+	gtk_binding_entry_remove (binding_set, GDK_Right, modifiers);
 }
 
 static void
@@ -262,11 +264,11 @@ remove_all_move_bindings (PanelWidget *panel)
 	remove_tab_bindings (binding_set, 0, TRUE);
 	remove_tab_bindings (binding_set, GDK_SHIFT_MASK, FALSE);
 
-	gtk_binding_entry_clear (binding_set, GDK_Escape, 0);
-	gtk_binding_entry_clear (binding_set, GDK_KP_Enter, 0);
-	gtk_binding_entry_clear (binding_set, GDK_Return, 0);
-	gtk_binding_entry_clear (binding_set, GDK_KP_Space, 0);
-	gtk_binding_entry_clear (binding_set, GDK_space, 0);
+	gtk_binding_entry_remove (binding_set, GDK_Escape, 0);
+	gtk_binding_entry_remove (binding_set, GDK_KP_Enter, 0);
+	gtk_binding_entry_remove (binding_set, GDK_Return, 0);
+	gtk_binding_entry_remove (binding_set, GDK_KP_Space, 0);
+	gtk_binding_entry_remove (binding_set, GDK_space, 0);
 }
 
 static void
@@ -578,7 +580,7 @@ panel_widget_cremove (GtkContainer *container, GtkWidget *widget)
 	if(panel->currently_dragged_applet == ad)
 		panel_widget_applet_drag_end(panel);
 
-	gtk_widget_ref(widget);
+	g_object_ref (widget);
 	if (GTK_CONTAINER_CLASS (panel_widget_parent_class)->remove)
 		(* GTK_CONTAINER_CLASS (panel_widget_parent_class)->remove) (container,
 								widget);
@@ -588,7 +590,7 @@ panel_widget_cremove (GtkContainer *container, GtkWidget *widget)
 	g_signal_emit (G_OBJECT (container),
 		       panel_widget_signals[APPLET_REMOVED_SIGNAL],
 		       0, widget);
-	gtk_widget_unref(widget);
+	g_object_unref (widget);
 }
 
 
@@ -1172,7 +1174,7 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 
 	ad = list->data;
 	do { 
-		i = ad->constrained;
+		i = ad->pos;
 		ad->pos = ad->constrained = pos--;
 		ad->cells = 1;
 		prev = list;
@@ -1180,7 +1182,7 @@ panel_widget_right_stick(PanelWidget *panel,int old_size)
 		if(!list)
 			break;
 		ad = list->data;
-	} while(ad->constrained + ad->cells == i);
+	} while(ad->pos + ad->cells == i);
 
 	for (list = prev; list; list = list->next)
 		emit_applet_moved (panel, list->data);
@@ -1311,7 +1313,7 @@ panel_widget_set_background_region (PanelWidget *panel)
 
 	widget = GTK_WIDGET (panel);
 
-	if (!GTK_WIDGET_REALIZED (widget))
+	if (!gtk_widget_get_realized (widget))
 		return;
 
 	gdk_window_get_origin (widget->window, &origin_x, &origin_y);
@@ -1341,7 +1343,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	ltr = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR;
 	
 	widget->allocation = *allocation;
-	if (GTK_WIDGET_REALIZED (widget))
+	if (gtk_widget_get_realized (widget))
 		gdk_window_move_resize (widget->window,
 					allocation->x, 
 					allocation->y,
@@ -1531,7 +1533,7 @@ panel_widget_is_cursor(PanelWidget *panel, int overlap)
 	
 	if(!widget ||
 	   !GTK_IS_WIDGET(widget) ||
-	   !GTK_WIDGET_VISIBLE(widget))
+	   !gtk_widget_get_visible(widget))
 		return FALSE;
 
 	gtk_widget_get_pointer(widget, &x, &y);
@@ -1550,7 +1552,7 @@ static void
 panel_widget_style_set (GtkWidget *widget,
 			GtkStyle  *previous_style)
 {
-	if (GTK_WIDGET_REALIZED (widget))
+	if (gtk_widget_get_realized (widget))
 		panel_background_set_default_style (
 			&PANEL_WIDGET (widget)->background,
 			&widget->style->bg [GTK_WIDGET_STATE (widget)],
@@ -1561,7 +1563,7 @@ static void
 panel_widget_state_changed (GtkWidget    *widget,
 			    GtkStateType  previous_state)
 {
-	if (GTK_WIDGET_REALIZED (widget))
+	if (gtk_widget_get_realized (widget))
 		panel_background_set_default_style (
 			&PANEL_WIDGET (widget)->background,
 			&widget->style->bg [GTK_WIDGET_STATE (widget)],
@@ -1588,6 +1590,10 @@ panel_widget_realize (GtkWidget *widget)
 
 	GTK_WIDGET_CLASS (panel_widget_parent_class)->realize (widget);
 
+	/* For auto-hidden panels with a colored background, we need native
+	 * windows to avoid some uglyness on unhide */
+	gdk_window_ensure_native (widget->window);
+
 	panel_background_set_default_style (
 		&panel->background,
 		&widget->style->bg [GTK_WIDGET_STATE (widget)],
@@ -2324,7 +2330,7 @@ bind_applet_events(GtkWidget *widget, gpointer data)
 	 * GtkEventBox) for processing by us.
 	 */
 	
-	if (!GTK_WIDGET_NO_WINDOW(widget))
+	if (gtk_widget_get_has_window (widget))
 		g_signal_connect (G_OBJECT(widget), "event",
 				  G_CALLBACK (panel_sub_event_handler),
 				  data);
@@ -2548,13 +2554,13 @@ panel_widget_reparent (PanelWidget *old_panel,
 	GtkWidget *focus_widget = NULL;
 	AppletInfo* info;
 
-	g_return_val_if_fail(PANEL_IS_WIDGET(old_panel),-1);
-	g_return_val_if_fail(PANEL_IS_WIDGET(new_panel),-1);
-	g_return_val_if_fail(GTK_IS_WIDGET(applet),-1);
-	g_return_val_if_fail(pos>=0,-1);
+	g_return_val_if_fail(PANEL_IS_WIDGET(old_panel), FALSE);
+	g_return_val_if_fail(PANEL_IS_WIDGET(new_panel), FALSE);
+	g_return_val_if_fail(GTK_IS_WIDGET(applet), FALSE);
+	g_return_val_if_fail(pos>=0, FALSE);
 
 	ad = g_object_get_data (G_OBJECT (applet), PANEL_APPLET_DATA);
-	g_return_val_if_fail(ad!=NULL,-1);
+	g_return_val_if_fail(ad!=NULL, FALSE);
 
 	/* Don't try and reparent to an explicitly hidden panel,
 	 * very confusing for the user ...
@@ -2581,7 +2587,7 @@ panel_widget_reparent (PanelWidget *old_panel,
 	if (info && info->type == PANEL_OBJECT_BONOBO)
 		panel_applet_frame_set_panel (PANEL_APPLET_FRAME (ad->applet), new_panel);
 
-	if (GTK_WIDGET_CAN_FOCUS (new_panel))
+	if (gtk_widget_get_can_focus (GTK_WIDGET (new_panel)))
 		GTK_WIDGET_UNSET_FLAGS (new_panel, GTK_CAN_FOCUS);
 	if (focus_widget) {
 		panel_widget_force_grab_focus (focus_widget);
@@ -2787,7 +2793,7 @@ static gboolean
 panel_widget_real_focus (GtkWidget        *widget,
                          GtkDirectionType  direction)
 {
-	if (GTK_WIDGET_CAN_FOCUS (widget) && GTK_FIXED (widget)->children) {
+	if (gtk_widget_get_can_focus (widget) && GTK_FIXED (widget)->children) {
 		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 	}
 	return GTK_WIDGET_CLASS (panel_widget_parent_class)->focus (widget, direction);
